#########
Prior art
#########


*****
About
*****

There are a few other projects on PyPI and GitHub, which are aiming at the same
goals like Skeem. Most notably are those excellent projects by `Catherine
Devlin`_ and `Iuliia Volkova`_. Skeem is currently based on ``ddlgenerator``.

- https://pypi.org/project/ddlgenerator/
- https://pypi.org/project/simple-ddl-parser/
- https://pypi.org/project/simple-ddl-generator/
- https://pypi.org/project/omymodels/
- https://pypi.org/project/py-models-parser/
- https://pypi.org/project/table-meta/

See also the impressive frictionless framework and toolkit by OKFN and friends.

- https://github.com/okfn/messytables
- https://github.com/frictionlessdata/tabulator-py
- https://github.com/frictionlessdata/framework

And of course, last but not least, the venerable `pandas.DataFrame.to_sql`_.


Miscellaneous
=============

A few other projects have not been evaluated yet, but may well contain some
gems like handlers for different input data formats.

- https://pypi.org/project/csv2postgresql/
- https://pypi.org/project/csv-schema-inference/
- https://pypi.org/project/csvkit/
- https://pypi.org/project/DDLJ/
- https://pypi.org/project/ddlparse/
- https://pypi.org/project/from-dict/
- https://pypi.org/project/json2hive/
- https://pypi.org/project/jsonschema2ddl/
- https://github.com/better/jsonschema2db
- https://pypi.org/project/jsonschema2rdbmsddl/
- https://pypi.org/project/jsontableschema/
- https://pypi.org/project/ninjasql/
- https://pypi.org/project/pg-metadata/
- https://pypi.org/project/postgres-ddl/
- https://pypi.org/project/type-infer/
- https://pypi.org/project/xlsx-from-json/
- https://pypi.org/project/xml2ddl/


.. _Catherine Devlin: https://github.com/catherinedevlin
.. _Iuliia Volkova: https://github.com/xnuinside
.. _pandas.DataFrame.to_sql: https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_sql.html
